@@ -95,7 +95,7 @@
 ;;   qualified version of a compatible type; the order of type qualifiers within
 ;;   a list of specifiers or qualifiers does not affect the specified type.
 
-;;(and=> (parse-file "exam.d/ex14.c") ppsx)
+;;(and=> (parse-file "c99-exam/ex14.c") ppsx)
 ;;(and=> (parse-c99x "(a*b)+c") ppsx)
 
 (define adecl #f)
@@ -111,15 +111,16 @@
        ;;(udecl (udict-ref udict "x"))
        ;;(mdecl (udecl->mspec udecl))
        ;;(tree (parse-c99x "((int)'q')"))
-       (tree (parse-file "exam.d/ex01.c"))
+       (tree (parse-file "c99-exam/ex01.c"))
        ;;(decl (sx-ref* tree 153)) ;; for zzz.e
        ;;(udecl (unitize-decl decl))
        ;;(udict (c99-trans-unit->udict tree))
        ;;(udecl (udict-struct-ref udict "epoll_event"))
        )
-  (ppsx tree)
+  ;;(ppsx tree)
   ;;(ppsx (eval-c99-cx tree))
   ;;(ppsx (get-gcc-inc-dirs))
+  (pp cpp-defs)
   #t)
 
 ;; --- last line ---
