@@ -1,23 +1,27 @@
-;;; lang/c/cpp.scm
-;;;
-;;; Copyright (C) 2015-2018 Matthew R. Wette
-;;;
-;;; This library is free software; you can redistribute it and/or
-;;; modify it under the terms of the GNU Lesser General Public
-;;; License as published by the Free Software Foundation; either
-;;; version 3 of the License, or (at your option) any later version.
-;;;
-;;; This library is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;;; Lesser General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU Lesser General Public License
-;;; along with this library; if not, see <http://www.gnu.org/licenses/>.
+;;; lang/c/cpp.scm - C preprocessor
+
+;; Copyright (C) 2015-2018 Matthew R. Wette
+;;
+;; This library is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU Lesser General Public
+;; License as published by the Free Software Foundation; either
+;; version 3 of the License, or (at your option) any later version.
+;;
+;; This library is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; Lesser General Public License for more details.
+;;
+;; You should have received a copy of the GNU Lesser General Public License
+;; along with this library; if not, see <http://www.gnu.org/licenses/>.
+
+;;; Notes:
 
 ;; C preprocessor macro expansion and condition text parse-and-eval
 ;; ref: https://gcc.gnu.org/onlinedocs/gcc-3.0.1/cpp_3.html
 
+;;; Code:
+
 (define-module (nyacc lang c99 cpp)
   #:export (
 	    cpp-line->stmt
@@ -215,10 +219,7 @@
 (include-from-path "nyacc/lang/c99/mach.d/cppact.scm")
 
 (define cpp-raw-parser
-  (make-lalr-parser
-   (list (cons 'len-v cpp-len-v) (cons 'pat-v cpp-pat-v)
-	 (cons 'rto-v cpp-rto-v) (cons 'mtab cpp-mtab)
-	 (cons 'act-v cpp-act-v))))
+  (make-lalr-parser (acons 'act-v cpp-act-v cpp-tables)))
 
 (define (cpp-err fmt . args)
   (apply throw 'cpp-error fmt args))
