@@ -1049,4 +1049,11 @@
     ("++" . 98) ("->" . 99) ("." . 100) ("]" . 101) ("[" . 102) ("}" . 103) 
     ("{" . 104) (")" . 105) ("(" . 106) ($error . 2) ($end . 108)))
 
+(define c99-tables
+  (list
+   (cons 'len-v c99-len-v)
+   (cons 'pat-v c99-pat-v)
+   (cons 'rto-v c99-rto-v)
+   (cons 'mtab c99-mtab)))
+
 ;;; end tables
